/*
 * Copyright 2014 Peter Olsson
 * 
 * This file is part of Brum Brum Rally.
 * 
 * Brum Brum Rally is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Brum Brum Rally is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "SettingsMenu.h"
#include "StateManager.h"
#include "MainMenu.h"
#include "GraphicsSettingsMenu.h"
#include "HumanPlayerSettingsMenu.h"
#include "ComputerPlayerSettingsMenu.h"
#include "TracksSettingsMenu.h"
#include "NetworkSettingsMenu.h"

SettingsMenu::SettingsMenu()
:	humanPlayesAction(false),
	computerPlayersAction(false),
	tracksAction(false),
	graphicsAction(false),
	networkAction(false),
	mainMenuAction(false)
{
	menu.setTitle("Settings");
	
	menu.addItem("Human players", &humanPlayesAction);
	menu.addItem("Computer players", &computerPlayersAction);
	menu.addItem("Tracks", &tracksAction);
	menu.addItem("Graphics", &graphicsAction);
	menu.addItem("Network", &networkAction);
	menu.addItem("Main menu", &mainMenuAction);
	
	menu.addRenderObjects(this);
}

void SettingsMenu::onEvent(const SDL_Event& event)
{
	StateManager& sm = StateManager::getInstance();
	MenuEvent me = sm.getMenuEvent(event);
	if (menu.onEvent(me))
	{
		if (humanPlayesAction)
		{
			sm.enter(new HumanPlayerSettingsMenu(), +1);
			return;
		}
		else if (computerPlayersAction)
		{
			sm.enter(new ComputerPlayerSettingsMenu(), +1);
			return;
		}
		else if (tracksAction)
		{
			sm.enter(new TracksSettingsMenu(), +1);
			return;
		}
		else if (graphicsAction)
		{
			sm.enter(new GraphicsSettingsMenu(), +1);
			return;
		}
		else if (networkAction)
		{
			sm.enter(new NetworkSettingsMenu(), +1);
			return;
		}
	}
	if (mainMenuAction || me.type == MENU_ESC)
	{
		sm.enter(new MainMenu(), -1);
	}
}
